/***************************************************************************
 begin                : Wed Aug 21 2002
 copyright            : (C) 2002 by Christian Hubinger
 email                : chubinger@irrsinnig.org.orphi.iki
***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef KMFIPTDOCOPTIONS_H
#define KMFIPTDOCOPTIONS_H

#include <tqwidget.h>
#include <tdemacros.h>
#include "kmyfirewalliptdocoptions.h"

/**
  *@author Christian Hubinger
  */

class TQString;

namespace KMF {
class KMFIPTDoc;

class TDE_EXPORT KMFIPTDocOptions : public KMyFirewallIPTDocOptions {
	TQ_OBJECT
  
public:
	KMFIPTDocOptions( TQWidget *parent = 0, const char *name = 0 );
	~KMFIPTDocOptions();
	void loadDoc( KMFIPTDoc* doc );

public slots:
	void slotHelp();
	void accept();
private:
	KMFIPTDoc* kmfdoc;
signals:
	void sigConfigChanged();

};
}
#endif
